# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.organizations_v1_api import OrganizationsV1Api


class TestOrganizationsV1Api(unittest.TestCase):
    """OrganizationsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationsV1Api()

    def tearDown(self) -> None:
        pass

    def test_delete_organization(self) -> None:
        """Test case for delete_organization

        Delete Organization.
        """
        pass

    def test_get_users_organization(self) -> None:
        """Test case for get_users_organization

        Get Users Organization.
        """
        pass

    def test_patch_organization(self) -> None:
        """Test case for patch_organization

        Patch Organization.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from arthur_client.api_bindings.models.anthropic_thinking_param import AnthropicThinkingParam
from arthur_client.api_bindings.models.logit_bias_item import LogitBiasItem
from arthur_client.api_bindings.models.reasoning_effort_enum import ReasoningEffortEnum
from typing import Optional, Set
from typing_extensions import Self

class LLMBaseConfigSettings(BaseModel):
    """
    LLMBaseConfigSettings
    """ # noqa: E501
    timeout: Optional[Union[StrictFloat, StrictInt]] = None
    temperature: Optional[Union[StrictFloat, StrictInt]] = None
    top_p: Optional[Union[StrictFloat, StrictInt]] = None
    max_tokens: Optional[StrictInt] = None
    stop: Optional[StrictStr] = None
    presence_penalty: Optional[Union[StrictFloat, StrictInt]] = None
    frequency_penalty: Optional[Union[StrictFloat, StrictInt]] = None
    seed: Optional[StrictInt] = None
    logprobs: Optional[StrictBool] = None
    top_logprobs: Optional[StrictInt] = None
    logit_bias: Optional[List[LogitBiasItem]] = None
    max_completion_tokens: Optional[StrictInt] = None
    reasoning_effort: Optional[ReasoningEffortEnum] = None
    thinking: Optional[AnthropicThinkingParam] = None
    __properties: ClassVar[List[str]] = ["timeout", "temperature", "top_p", "max_tokens", "stop", "presence_penalty", "frequency_penalty", "seed", "logprobs", "top_logprobs", "logit_bias", "max_completion_tokens", "reasoning_effort", "thinking"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LLMBaseConfigSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in logit_bias (list)
        _items = []
        if self.logit_bias:
            for _item_logit_bias in self.logit_bias:
                if _item_logit_bias:
                    _items.append(_item_logit_bias.to_dict())
            _dict['logit_bias'] = _items
        # override the default output from pydantic by calling `to_dict()` of thinking
        if self.thinking:
            _dict['thinking'] = self.thinking.to_dict()
        # set to None if timeout (nullable) is None
        # and model_fields_set contains the field
        if self.timeout is None and "timeout" in self.model_fields_set:
            _dict['timeout'] = None

        # set to None if temperature (nullable) is None
        # and model_fields_set contains the field
        if self.temperature is None and "temperature" in self.model_fields_set:
            _dict['temperature'] = None

        # set to None if top_p (nullable) is None
        # and model_fields_set contains the field
        if self.top_p is None and "top_p" in self.model_fields_set:
            _dict['top_p'] = None

        # set to None if max_tokens (nullable) is None
        # and model_fields_set contains the field
        if self.max_tokens is None and "max_tokens" in self.model_fields_set:
            _dict['max_tokens'] = None

        # set to None if stop (nullable) is None
        # and model_fields_set contains the field
        if self.stop is None and "stop" in self.model_fields_set:
            _dict['stop'] = None

        # set to None if presence_penalty (nullable) is None
        # and model_fields_set contains the field
        if self.presence_penalty is None and "presence_penalty" in self.model_fields_set:
            _dict['presence_penalty'] = None

        # set to None if frequency_penalty (nullable) is None
        # and model_fields_set contains the field
        if self.frequency_penalty is None and "frequency_penalty" in self.model_fields_set:
            _dict['frequency_penalty'] = None

        # set to None if seed (nullable) is None
        # and model_fields_set contains the field
        if self.seed is None and "seed" in self.model_fields_set:
            _dict['seed'] = None

        # set to None if logprobs (nullable) is None
        # and model_fields_set contains the field
        if self.logprobs is None and "logprobs" in self.model_fields_set:
            _dict['logprobs'] = None

        # set to None if top_logprobs (nullable) is None
        # and model_fields_set contains the field
        if self.top_logprobs is None and "top_logprobs" in self.model_fields_set:
            _dict['top_logprobs'] = None

        # set to None if logit_bias (nullable) is None
        # and model_fields_set contains the field
        if self.logit_bias is None and "logit_bias" in self.model_fields_set:
            _dict['logit_bias'] = None

        # set to None if max_completion_tokens (nullable) is None
        # and model_fields_set contains the field
        if self.max_completion_tokens is None and "max_completion_tokens" in self.model_fields_set:
            _dict['max_completion_tokens'] = None

        # set to None if reasoning_effort (nullable) is None
        # and model_fields_set contains the field
        if self.reasoning_effort is None and "reasoning_effort" in self.model_fields_set:
            _dict['reasoning_effort'] = None

        # set to None if thinking (nullable) is None
        # and model_fields_set contains the field
        if self.thinking is None and "thinking" in self.model_fields_set:
            _dict['thinking'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LLMBaseConfigSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "timeout": obj.get("timeout"),
            "temperature": obj.get("temperature"),
            "top_p": obj.get("top_p"),
            "max_tokens": obj.get("max_tokens"),
            "stop": obj.get("stop"),
            "presence_penalty": obj.get("presence_penalty"),
            "frequency_penalty": obj.get("frequency_penalty"),
            "seed": obj.get("seed"),
            "logprobs": obj.get("logprobs"),
            "top_logprobs": obj.get("top_logprobs"),
            "logit_bias": [LogitBiasItem.from_dict(_item) for _item in obj["logit_bias"]] if obj.get("logit_bias") is not None else None,
            "max_completion_tokens": obj.get("max_completion_tokens"),
            "reasoning_effort": obj.get("reasoning_effort"),
            "thinking": AnthropicThinkingParam.from_dict(obj["thinking"]) if obj.get("thinking") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.infinite_resource_list_alert_group import InfiniteResourceListAlertGroup

class TestInfiniteResourceListAlertGroup(unittest.TestCase):
    """InfiniteResourceListAlertGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InfiniteResourceListAlertGroup:
        """Test InfiniteResourceListAlertGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InfiniteResourceListAlertGroup`
        """
        model = InfiniteResourceListAlertGroup()
        if include_optional:
            return InfiniteResourceListAlertGroup(
                records = [
                    arthur_client.api_bindings.models.alert_group.AlertGroup(
                        alert_rule_id = '', 
                        alert_rule_name = '', 
                        count = 56, 
                        latest_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        model_id = '', 
                        model_name = '', 
                        bound = 'upper_bound', 
                        alerts = [
                            arthur_client.api_bindings.models.alert.Alert(
                                description = '', 
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                value = 1.337, 
                                threshold = 1.337, 
                                bound = 'upper_bound', 
                                interval = arthur_client.api_bindings.models.alert_rule_interval.AlertRuleInterval(
                                    unit = 'seconds', 
                                    count = 56, ), 
                                dimensions = arthur_client.api_bindings.models.dimensions.dimensions(), 
                                alert_rule_id = '', 
                                job_id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                model_id = '', 
                                alert_rule_name = '', 
                                alert_rule_metric_name = '', 
                                is_duplicate_of = '', )
                            ], )
                    ],
                pagination = arthur_client.api_bindings.models.infinite_pagination.InfinitePagination(
                    page = 56, 
                    page_size = 56, )
            )
        else:
            return InfiniteResourceListAlertGroup(
                records = [
                    arthur_client.api_bindings.models.alert_group.AlertGroup(
                        alert_rule_id = '', 
                        alert_rule_name = '', 
                        count = 56, 
                        latest_timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        model_id = '', 
                        model_name = '', 
                        bound = 'upper_bound', 
                        alerts = [
                            arthur_client.api_bindings.models.alert.Alert(
                                description = '', 
                                timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                value = 1.337, 
                                threshold = 1.337, 
                                bound = 'upper_bound', 
                                interval = arthur_client.api_bindings.models.alert_rule_interval.AlertRuleInterval(
                                    unit = 'seconds', 
                                    count = 56, ), 
                                dimensions = arthur_client.api_bindings.models.dimensions.dimensions(), 
                                alert_rule_id = '', 
                                job_id = '', 
                                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                id = '', 
                                model_id = '', 
                                alert_rule_name = '', 
                                alert_rule_metric_name = '', 
                                is_duplicate_of = '', )
                            ], )
                    ],
                pagination = arthur_client.api_bindings.models.infinite_pagination.InfinitePagination(
                    page = 56, 
                    page_size = 56, ),
        )
        """

    def testInfiniteResourceListAlertGroup(self):
        """Test InfiniteResourceListAlertGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from arthur_client.api_bindings.api.agents_v1_api import AgentsV1Api
from arthur_client.api_bindings.api.alert_rules_v1_api import AlertRulesV1Api
from arthur_client.api_bindings.api.alerts_v1_api import AlertsV1Api
from arthur_client.api_bindings.api.authorization_v1_api import AuthorizationV1Api
from arthur_client.api_bindings.api.connector_schemas_v1_api import ConnectorSchemasV1Api
from arthur_client.api_bindings.api.connectors_v1_api import ConnectorsV1Api
from arthur_client.api_bindings.api.custom_aggregation_tests_v1_api import CustomAggregationTestsV1Api
from arthur_client.api_bindings.api.custom_aggregations_v1_api import CustomAggregationsV1Api
from arthur_client.api_bindings.api.data_plane_associations_v1_api import DataPlaneAssociationsV1Api
from arthur_client.api_bindings.api.data_planes_v1_api import DataPlanesV1Api
from arthur_client.api_bindings.api.data_retrieval_v1_api import DataRetrievalV1Api
from arthur_client.api_bindings.api.datasets_v1_api import DatasetsV1Api
from arthur_client.api_bindings.api.feature_flags_v1_api import FeatureFlagsV1Api
from arthur_client.api_bindings.api.groups_v1_api import GroupsV1Api
from arthur_client.api_bindings.api.jobs_v1_api import JobsV1Api
from arthur_client.api_bindings.api.metric_functions_v1_api import MetricFunctionsV1Api
from arthur_client.api_bindings.api.metrics_v1_api import MetricsV1Api
from arthur_client.api_bindings.api.models_v1_api import ModelsV1Api
from arthur_client.api_bindings.api.o_auth_v1_api import OAuthV1Api
from arthur_client.api_bindings.api.organizations_v1_api import OrganizationsV1Api
from arthur_client.api_bindings.api.projects_v1_api import ProjectsV1Api
from arthur_client.api_bindings.api.registration_v1_api import RegistrationV1Api
from arthur_client.api_bindings.api.roles_v1_api import RolesV1Api
from arthur_client.api_bindings.api.tasks_v1_api import TasksV1Api
from arthur_client.api_bindings.api.unregistered_agents_v1_api import UnregisteredAgentsV1Api
from arthur_client.api_bindings.api.upsolve_v1_api import UpsolveV1Api
from arthur_client.api_bindings.api.users_v1_api import UsersV1Api
from arthur_client.api_bindings.api.webhooks_v1_api import WebhooksV1Api
from arthur_client.api_bindings.api.workspaces_v1_api import WorkspacesV1Api
from arthur_client.api_bindings.api.default_api import DefaultApi




# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from arthur_client.api_bindings.models.creation_source import CreationSource
from arthur_client.api_bindings.models.infrastructure import Infrastructure
from arthur_client.api_bindings.models.sub_agent_response import SubAgentResponse
from arthur_client.api_bindings.models.tool_response import ToolResponse
from typing import Optional, Set
from typing_extensions import Self

class UnregisteredAgentResponse(BaseModel):
    """
    Response model for an unregistered agent with assigned ID.
    """ # noqa: E501
    created_at: datetime = Field(description="Time of record creation.")
    updated_at: datetime = Field(description="Time of last record update.")
    id: StrictStr = Field(description="ID of the unregistered agent.")
    name: StrictStr = Field(description="Name of the unregistered agent.")
    creation_source: CreationSource = Field(description="Information about how this agent was created.")
    first_detected: datetime = Field(description="Timestamp when this agent was first detected.")
    num_spans: Optional[StrictInt] = None
    infrastructure: Infrastructure = Field(description="Infrastructure where this agent is running.")
    data_plane_id: StrictStr = Field(description="UUID of the data plane where this agent was detected.")
    tools: Optional[List[ToolResponse]] = Field(default=None, description="List of tools used by this agent.")
    sub_agents: Optional[List[SubAgentResponse]] = Field(default=None, description="List of sub-agents used by this agent.")
    model_id: Optional[StrictStr] = None
    model_name: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["created_at", "updated_at", "id", "name", "creation_source", "first_detected", "num_spans", "infrastructure", "data_plane_id", "tools", "sub_agents", "model_id", "model_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UnregisteredAgentResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of creation_source
        if self.creation_source:
            _dict['creation_source'] = self.creation_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in tools (list)
        _items = []
        if self.tools:
            for _item_tools in self.tools:
                if _item_tools:
                    _items.append(_item_tools.to_dict())
            _dict['tools'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in sub_agents (list)
        _items = []
        if self.sub_agents:
            for _item_sub_agents in self.sub_agents:
                if _item_sub_agents:
                    _items.append(_item_sub_agents.to_dict())
            _dict['sub_agents'] = _items
        # set to None if num_spans (nullable) is None
        # and model_fields_set contains the field
        if self.num_spans is None and "num_spans" in self.model_fields_set:
            _dict['num_spans'] = None

        # set to None if model_id (nullable) is None
        # and model_fields_set contains the field
        if self.model_id is None and "model_id" in self.model_fields_set:
            _dict['model_id'] = None

        # set to None if model_name (nullable) is None
        # and model_fields_set contains the field
        if self.model_name is None and "model_name" in self.model_fields_set:
            _dict['model_name'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UnregisteredAgentResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "id": obj.get("id"),
            "name": obj.get("name"),
            "creation_source": CreationSource.from_dict(obj["creation_source"]) if obj.get("creation_source") is not None else None,
            "first_detected": obj.get("first_detected"),
            "num_spans": obj.get("num_spans"),
            "infrastructure": obj.get("infrastructure"),
            "data_plane_id": obj.get("data_plane_id"),
            "tools": [ToolResponse.from_dict(_item) for _item in obj["tools"]] if obj.get("tools") is not None else None,
            "sub_agents": [SubAgentResponse.from_dict(_item) for _item in obj["sub_agents"]] if obj.get("sub_agents") is not None else None,
            "model_id": obj.get("model_id"),
            "model_name": obj.get("model_name")
        })
        return _obj





# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.continuous_eval_response import ContinuousEvalResponse

class TestContinuousEvalResponse(unittest.TestCase):
    """ContinuousEvalResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ContinuousEvalResponse:
        """Test ContinuousEvalResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ContinuousEvalResponse`
        """
        model = ContinuousEvalResponse()
        if include_optional:
            return ContinuousEvalResponse(
                id = '',
                name = '',
                description = '',
                task_id = '',
                llm_eval_name = '',
                llm_eval_version = 56,
                transform_id = '',
                transform_variable_mapping = [
                    arthur_client.api_bindings.models.continuous_eval_transform_variable_mapping_response.ContinuousEvalTransformVariableMappingResponse(
                        transform_variable = '', 
                        eval_variable = '', )
                    ],
                enabled = True,
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return ContinuousEvalResponse(
                id = '',
                name = '',
                task_id = '',
                llm_eval_name = '',
                llm_eval_version = 56,
                transform_id = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testContinuousEvalResponse(self):
        """Test ContinuousEvalResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.put_available_datasets import PutAvailableDatasets

class TestPutAvailableDatasets(unittest.TestCase):
    """PutAvailableDatasets unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PutAvailableDatasets:
        """Test PutAvailableDatasets
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PutAvailableDatasets`
        """
        model = PutAvailableDatasets()
        if include_optional:
            return PutAvailableDatasets(
                available_datasets = [
                    arthur_client.api_bindings.models.put_available_dataset.PutAvailableDataset(
                        name = '', 
                        dataset_locator = arthur_client.api_bindings.models.dataset_locator.DatasetLocator(
                            fields = [
                                arthur_client.api_bindings.models.dataset_locator_field.DatasetLocatorField(
                                    key = '', 
                                    value = '', )
                                ], ), 
                        dataset_schema = arthur_client.api_bindings.models.put_dataset_schema.PutDatasetSchema(
                            alias_mask = {
                                'key' : ''
                                }, 
                            columns = [
                                arthur_client.api_bindings.models.dataset_column.DatasetColumn(
                                    id = '', 
                                    source_name = '', 
                                    definition = null, )
                                ], ), 
                        model_problem_type = 'regression', 
                        dataset_join_spec = arthur_client.api_bindings.models.post_dataset_join_spec.PostDatasetJoinSpec(
                            left_dataset_id = '', 
                            right_dataset_id = '', 
                            left_dataset_join_key = '', 
                            right_dataset_join_key = '', 
                            join_type = 'inner', ), 
                        is_static = True, )
                    ]
            )
        else:
            return PutAvailableDatasets(
                available_datasets = [
                    arthur_client.api_bindings.models.put_available_dataset.PutAvailableDataset(
                        name = '', 
                        dataset_locator = arthur_client.api_bindings.models.dataset_locator.DatasetLocator(
                            fields = [
                                arthur_client.api_bindings.models.dataset_locator_field.DatasetLocatorField(
                                    key = '', 
                                    value = '', )
                                ], ), 
                        dataset_schema = arthur_client.api_bindings.models.put_dataset_schema.PutDatasetSchema(
                            alias_mask = {
                                'key' : ''
                                }, 
                            columns = [
                                arthur_client.api_bindings.models.dataset_column.DatasetColumn(
                                    id = '', 
                                    source_name = '', 
                                    definition = null, )
                                ], ), 
                        model_problem_type = 'regression', 
                        dataset_join_spec = arthur_client.api_bindings.models.post_dataset_join_spec.PostDatasetJoinSpec(
                            left_dataset_id = '', 
                            right_dataset_id = '', 
                            left_dataset_join_key = '', 
                            right_dataset_join_key = '', 
                            join_type = 'inner', ), 
                        is_static = True, )
                    ],
        )
        """

    def testPutAvailableDatasets(self):
        """Test PutAvailableDatasets"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.0"

# import apis into sdk package
from arthur_client.api_bindings.api.agents_v1_api import AgentsV1Api
from arthur_client.api_bindings.api.alert_rules_v1_api import AlertRulesV1Api
from arthur_client.api_bindings.api.alerts_v1_api import AlertsV1Api
from arthur_client.api_bindings.api.authorization_v1_api import AuthorizationV1Api
from arthur_client.api_bindings.api.connector_schemas_v1_api import ConnectorSchemasV1Api
from arthur_client.api_bindings.api.connectors_v1_api import ConnectorsV1Api
from arthur_client.api_bindings.api.custom_aggregation_tests_v1_api import CustomAggregationTestsV1Api
from arthur_client.api_bindings.api.custom_aggregations_v1_api import CustomAggregationsV1Api
from arthur_client.api_bindings.api.data_plane_associations_v1_api import DataPlaneAssociationsV1Api
from arthur_client.api_bindings.api.data_planes_v1_api import DataPlanesV1Api
from arthur_client.api_bindings.api.data_retrieval_v1_api import DataRetrievalV1Api
from arthur_client.api_bindings.api.datasets_v1_api import DatasetsV1Api
from arthur_client.api_bindings.api.feature_flags_v1_api import FeatureFlagsV1Api
from arthur_client.api_bindings.api.groups_v1_api import GroupsV1Api
from arthur_client.api_bindings.api.jobs_v1_api import JobsV1Api
from arthur_client.api_bindings.api.metric_functions_v1_api import MetricFunctionsV1Api
from arthur_client.api_bindings.api.metrics_v1_api import MetricsV1Api
from arthur_client.api_bindings.api.models_v1_api import ModelsV1Api
from arthur_client.api_bindings.api.o_auth_v1_api import OAuthV1Api
from arthur_client.api_bindings.api.organizations_v1_api import OrganizationsV1Api
from arthur_client.api_bindings.api.projects_v1_api import ProjectsV1Api
from arthur_client.api_bindings.api.registration_v1_api import RegistrationV1Api
from arthur_client.api_bindings.api.roles_v1_api import RolesV1Api
from arthur_client.api_bindings.api.tasks_v1_api import TasksV1Api
from arthur_client.api_bindings.api.unregistered_agents_v1_api import UnregisteredAgentsV1Api
from arthur_client.api_bindings.api.upsolve_v1_api import UpsolveV1Api
from arthur_client.api_bindings.api.users_v1_api import UsersV1Api
from arthur_client.api_bindings.api.webhooks_v1_api import WebhooksV1Api
from arthur_client.api_bindings.api.workspaces_v1_api import WorkspacesV1Api
from arthur_client.api_bindings.api.default_api import DefaultApi

# import ApiClient
from arthur_client.api_bindings.api_response import ApiResponse
from arthur_client.api_bindings.api_client import ApiClient
from arthur_client.api_bindings.configuration import Configuration
from arthur_client.api_bindings.exceptions import OpenApiException
from arthur_client.api_bindings.exceptions import ApiTypeError
from arthur_client.api_bindings.exceptions import ApiValueError
from arthur_client.api_bindings.exceptions import ApiKeyError
from arthur_client.api_bindings.exceptions import ApiAttributeError
from arthur_client.api_bindings.exceptions import ApiException

# import models into sdk package
from arthur_client.api_bindings.models.agent import Agent
from arthur_client.api_bindings.models.agent_creation_source import AgentCreationSource
from arthur_client.api_bindings.models.agent_metadata import AgentMetadata
from arthur_client.api_bindings.models.agent_metadata_response import AgentMetadataResponse
from arthur_client.api_bindings.models.agent_response import AgentResponse
from arthur_client.api_bindings.models.agent_sort import AgentSort
from arthur_client.api_bindings.models.aggregation_kind import AggregationKind
from arthur_client.api_bindings.models.aggregation_metric_type import AggregationMetricType
from arthur_client.api_bindings.models.aggregation_spec import AggregationSpec
from arthur_client.api_bindings.models.aggregation_spec_schema import AggregationSpecSchema
from arthur_client.api_bindings.models.aggregation_spec_schema_init_args_inner import AggregationSpecSchemaInitArgsInner
from arthur_client.api_bindings.models.alert import Alert
from arthur_client.api_bindings.models.alert_bound import AlertBound
from arthur_client.api_bindings.models.alert_check_job_spec import AlertCheckJobSpec
from arthur_client.api_bindings.models.alert_group import AlertGroup
from arthur_client.api_bindings.models.alert_rule import AlertRule
from arthur_client.api_bindings.models.alert_rule_interval import AlertRuleInterval
from arthur_client.api_bindings.models.alert_rule_notification_webhook import AlertRuleNotificationWebhook
from arthur_client.api_bindings.models.alert_rule_sql_validation_resp import AlertRuleSQLValidationResp
from arthur_client.api_bindings.models.alert_rule_sort import AlertRuleSort
from arthur_client.api_bindings.models.alert_sort import AlertSort
from arthur_client.api_bindings.models.alert_webhook_called import AlertWebhookCalled
from arthur_client.api_bindings.models.anthropic_thinking_param import AnthropicThinkingParam
from arthur_client.api_bindings.models.available_dataset import AvailableDataset
from arthur_client.api_bindings.models.available_datasets_sort import AvailableDatasetsSort
from arthur_client.api_bindings.models.bad_request_error import BadRequestError
from arthur_client.api_bindings.models.base_column_parameter_schema import BaseColumnParameterSchema
from arthur_client.api_bindings.models.base_column_parameter_schema_allowed_column_types_inner import BaseColumnParameterSchemaAllowedColumnTypesInner
from arthur_client.api_bindings.models.base_dataset_parameter_schema import BaseDatasetParameterSchema
from arthur_client.api_bindings.models.base_literal_parameter_schema import BaseLiteralParameterSchema
from arthur_client.api_bindings.models.base_reported_aggregation import BaseReportedAggregation
from arthur_client.api_bindings.models.base_role import BaseRole
from arthur_client.api_bindings.models.bound_member import BoundMember
from arthur_client.api_bindings.models.bound_member_kind import BoundMemberKind
from arthur_client.api_bindings.models.bound_resource import BoundResource
from arthur_client.api_bindings.models.bound_resource_kind import BoundResourceKind
from arthur_client.api_bindings.models.bound_role import BoundRole
from arthur_client.api_bindings.models.config import Config
from arthur_client.api_bindings.models.conflict_error import ConflictError
from arthur_client.api_bindings.models.connector_check_job_spec import ConnectorCheckJobSpec
from arthur_client.api_bindings.models.connector_check_outcome import ConnectorCheckOutcome
from arthur_client.api_bindings.models.connector_check_result import ConnectorCheckResult
from arthur_client.api_bindings.models.connector_field_data_type import ConnectorFieldDataType
from arthur_client.api_bindings.models.connector_pagination_options import ConnectorPaginationOptions
from arthur_client.api_bindings.models.connector_spec import ConnectorSpec
from arthur_client.api_bindings.models.connector_spec_field import ConnectorSpecField
from arthur_client.api_bindings.models.connector_spec_field_with_metadata import ConnectorSpecFieldWithMetadata
from arthur_client.api_bindings.models.connector_spec_schema import ConnectorSpecSchema
from arthur_client.api_bindings.models.connector_spec_schema_field import ConnectorSpecSchemaField
from arthur_client.api_bindings.models.connector_type import ConnectorType
from arthur_client.api_bindings.models.connectors_sort import ConnectorsSort
from arthur_client.api_bindings.models.continuous_eval_response import ContinuousEvalResponse
from arthur_client.api_bindings.models.continuous_eval_transform_variable_mapping_response import ContinuousEvalTransformVariableMappingResponse
from arthur_client.api_bindings.models.create_model_link_task_job_spec import CreateModelLinkTaskJobSpec
from arthur_client.api_bindings.models.create_model_task_job_spec import CreateModelTaskJobSpec
from arthur_client.api_bindings.models.created_alerts import CreatedAlerts
from arthur_client.api_bindings.models.creation_source import CreationSource
from arthur_client.api_bindings.models.credentials import Credentials
from arthur_client.api_bindings.models.custom_aggregation_spec_schema import CustomAggregationSpecSchema
from arthur_client.api_bindings.models.custom_aggregation_test_result import CustomAggregationTestResult
from arthur_client.api_bindings.models.custom_aggregation_test_spec import CustomAggregationTestSpec
from arthur_client.api_bindings.models.custom_aggregation_test_status import CustomAggregationTestStatus
from arthur_client.api_bindings.models.custom_aggregation_version_spec_schema import CustomAggregationVersionSpecSchema
from arthur_client.api_bindings.models.custom_aggregation_version_spec_schema_aggregate_args_inner import CustomAggregationVersionSpecSchemaAggregateArgsInner
from arthur_client.api_bindings.models.d_type import DType
from arthur_client.api_bindings.models.data_plane import DataPlane
from arthur_client.api_bindings.models.data_plane_association import DataPlaneAssociation
from arthur_client.api_bindings.models.data_plane_association_sort import DataPlaneAssociationSort
from arthur_client.api_bindings.models.data_plane_capabilities import DataPlaneCapabilities
from arthur_client.api_bindings.models.data_plane_sort import DataPlaneSort
from arthur_client.api_bindings.models.data_result_filter import DataResultFilter
from arthur_client.api_bindings.models.data_result_filter_op import DataResultFilterOp
from arthur_client.api_bindings.models.data_retrieval_data import DataRetrievalData
from arthur_client.api_bindings.models.data_retrieval_operation import DataRetrievalOperation
from arthur_client.api_bindings.models.data_retrieval_status import DataRetrievalStatus
from arthur_client.api_bindings.models.data_source import DataSource
from arthur_client.api_bindings.models.data_source_response import DataSourceResponse
from arthur_client.api_bindings.models.dataset import Dataset
from arthur_client.api_bindings.models.dataset_column import DatasetColumn
from arthur_client.api_bindings.models.dataset_connector import DatasetConnector
from arthur_client.api_bindings.models.dataset_join_kind import DatasetJoinKind
from arthur_client.api_bindings.models.dataset_join_spec import DatasetJoinSpec
from arthur_client.api_bindings.models.dataset_list_type import DatasetListType
from arthur_client.api_bindings.models.dataset_locator import DatasetLocator
from arthur_client.api_bindings.models.dataset_locator_field import DatasetLocatorField
from arthur_client.api_bindings.models.dataset_locator_field_data_type import DatasetLocatorFieldDataType
from arthur_client.api_bindings.models.dataset_locator_schema import DatasetLocatorSchema
from arthur_client.api_bindings.models.dataset_locator_schema_field import DatasetLocatorSchemaField
from arthur_client.api_bindings.models.dataset_object_type import DatasetObjectType
from arthur_client.api_bindings.models.dataset_reference import DatasetReference
from arthur_client.api_bindings.models.dataset_scalar_type import DatasetScalarType
from arthur_client.api_bindings.models.dataset_schema import DatasetSchema
from arthur_client.api_bindings.models.datasets_sort import DatasetsSort
from arthur_client.api_bindings.models.definition import Definition
from arthur_client.api_bindings.models.delete_group_membership import DeleteGroupMembership
from arthur_client.api_bindings.models.delete_model_task_job_spec import DeleteModelTaskJobSpec
from arthur_client.api_bindings.models.dimension import Dimension
from arthur_client.api_bindings.models.discover_agents_job_spec import DiscoverAgentsJobSpec
from arthur_client.api_bindings.models.example_config import ExampleConfig
from arthur_client.api_bindings.models.examples_config import ExamplesConfig
from arthur_client.api_bindings.models.extended_role import ExtendedRole
from arthur_client.api_bindings.models.fetch_data_job_spec import FetchDataJobSpec
from arthur_client.api_bindings.models.fetch_model_task_job_spec import FetchModelTaskJobSpec
from arthur_client.api_bindings.models.gcp_agent_creation_source import GCPAgentCreationSource
from arthur_client.api_bindings.models.gcp_agent_metadata import GCPAgentMetadata
from arthur_client.api_bindings.models.gcp_agent_metadata_response import GCPAgentMetadataResponse
from arthur_client.api_bindings.models.generate_metrics_spec_request import GenerateMetricsSpecRequest
from arthur_client.api_bindings.models.group import Group
from arthur_client.api_bindings.models.group_membership import GroupMembership
from arthur_client.api_bindings.models.group_sort import GroupSort
from arthur_client.api_bindings.models.http_validation_error import HTTPValidationError
from arthur_client.api_bindings.models.health_status import HealthStatus
from arthur_client.api_bindings.models.infinite_pagination import InfinitePagination
from arthur_client.api_bindings.models.infinite_resource_list_alert import InfiniteResourceListAlert
from arthur_client.api_bindings.models.infinite_resource_list_alert_group import InfiniteResourceListAlertGroup
from arthur_client.api_bindings.models.infinite_resource_list_job import InfiniteResourceListJob
from arthur_client.api_bindings.models.infrastructure import Infrastructure
from arthur_client.api_bindings.models.infrastructure_list import InfrastructureList
from arthur_client.api_bindings.models.internal_server_error import InternalServerError
from arthur_client.api_bindings.models.interval_unit import IntervalUnit
from arthur_client.api_bindings.models.invite_new_user import InviteNewUser
from arthur_client.api_bindings.models.items import Items
from arthur_client.api_bindings.models.items1 import Items1
from arthur_client.api_bindings.models.job import Job
from arthur_client.api_bindings.models.job_dequeue_parameters import JobDequeueParameters
from arthur_client.api_bindings.models.job_error import JobError
from arthur_client.api_bindings.models.job_errors import JobErrors
from arthur_client.api_bindings.models.job_kind import JobKind
from arthur_client.api_bindings.models.job_log import JobLog
from arthur_client.api_bindings.models.job_log_level import JobLogLevel
from arthur_client.api_bindings.models.job_logs import JobLogs
from arthur_client.api_bindings.models.job_priority import JobPriority
from arthur_client.api_bindings.models.job_run import JobRun
from arthur_client.api_bindings.models.job_spec import JobSpec
from arthur_client.api_bindings.models.job_state import JobState
from arthur_client.api_bindings.models.job_trigger import JobTrigger
from arthur_client.api_bindings.models.jobs_batch import JobsBatch
from arthur_client.api_bindings.models.jobs_sort import JobsSort
from arthur_client.api_bindings.models.joined_dataset import JoinedDataset
from arthur_client.api_bindings.models.keywords_config import KeywordsConfig
from arthur_client.api_bindings.models.llm_base_config_settings import LLMBaseConfigSettings
from arthur_client.api_bindings.models.llm_eval import LLMEval
from arthur_client.api_bindings.models.llm_model import LLMModel
from arthur_client.api_bindings.models.llm_model_response import LLMModelResponse
from arthur_client.api_bindings.models.list_datasets_job_spec import ListDatasetsJobSpec
from arthur_client.api_bindings.models.list_type import ListType
from arthur_client.api_bindings.models.logit_bias_item import LogitBiasItem
from arthur_client.api_bindings.models.manual_agent_creation_source import ManualAgentCreationSource
from arthur_client.api_bindings.models.metric_response import MetricResponse
from arthur_client.api_bindings.models.metric_type import MetricType
from arthur_client.api_bindings.models.metrics_arg_spec import MetricsArgSpec
from arthur_client.api_bindings.models.metrics_calculation_job_spec import MetricsCalculationJobSpec
from arthur_client.api_bindings.models.metrics_column_list_parameter_schema import MetricsColumnListParameterSchema
from arthur_client.api_bindings.models.metrics_column_parameter_schema import MetricsColumnParameterSchema
from arthur_client.api_bindings.models.metrics_dataset_parameter_schema import MetricsDatasetParameterSchema
from arthur_client.api_bindings.models.metrics_literal_parameter_schema import MetricsLiteralParameterSchema
from arthur_client.api_bindings.models.metrics_query_result import MetricsQueryResult
from arthur_client.api_bindings.models.metrics_result_filter_op import MetricsResultFilterOp
from arthur_client.api_bindings.models.metrics_upload import MetricsUpload
from arthur_client.api_bindings.models.metrics_upload_metrics_inner import MetricsUploadMetricsInner
from arthur_client.api_bindings.models.metrics_upload_result import MetricsUploadResult
from arthur_client.api_bindings.models.metrics_version import MetricsVersion
from arthur_client.api_bindings.models.metrics_versions_sort import MetricsVersionsSort
from arthur_client.api_bindings.models.model import Model
from arthur_client.api_bindings.models.model_metric_spec import ModelMetricSpec
from arthur_client.api_bindings.models.model_metrics_schedule import ModelMetricsSchedule
from arthur_client.api_bindings.models.model_problem_type import ModelProblemType
from arthur_client.api_bindings.models.model_provider import ModelProvider
from arthur_client.api_bindings.models.models_sort import ModelsSort
from arthur_client.api_bindings.models.new_metric_request import NewMetricRequest
from arthur_client.api_bindings.models.new_rule_request import NewRuleRequest
from arthur_client.api_bindings.models.not_found_error import NotFoundError
from arthur_client.api_bindings.models.numeric_custom_aggregation_test_result import NumericCustomAggregationTestResult
from arthur_client.api_bindings.models.numeric_metric import NumericMetric
from arthur_client.api_bindings.models.numeric_point import NumericPoint
from arthur_client.api_bindings.models.numeric_time_series import NumericTimeSeries
from arthur_client.api_bindings.models.otel_agent_creation_source import OTELAgentCreationSource
from arthur_client.api_bindings.models.object_type import ObjectType
from arthur_client.api_bindings.models.object_value import ObjectValue
from arthur_client.api_bindings.models.organization import Organization
from arthur_client.api_bindings.models.pii_config import PIIConfig
from arthur_client.api_bindings.models.pagination import Pagination
from arthur_client.api_bindings.models.patch_alert_rule import PatchAlertRule
from arthur_client.api_bindings.models.patch_connector_spec import PatchConnectorSpec
from arthur_client.api_bindings.models.patch_custom_aggregation_spec_schema import PatchCustomAggregationSpecSchema
from arthur_client.api_bindings.models.patch_data_plane import PatchDataPlane
from arthur_client.api_bindings.models.patch_data_plane_capabilities import PatchDataPlaneCapabilities
from arthur_client.api_bindings.models.patch_dataset import PatchDataset
from arthur_client.api_bindings.models.patch_dataset_locator import PatchDatasetLocator
from arthur_client.api_bindings.models.patch_group import PatchGroup
from arthur_client.api_bindings.models.patch_job import PatchJob
from arthur_client.api_bindings.models.patch_model import PatchModel
from arthur_client.api_bindings.models.patch_organization import PatchOrganization
from arthur_client.api_bindings.models.patch_project import PatchProject
from arthur_client.api_bindings.models.patch_service_account_user import PatchServiceAccountUser
from arthur_client.api_bindings.models.patch_task_request import PatchTaskRequest
from arthur_client.api_bindings.models.patch_unregistered_agent import PatchUnregisteredAgent
from arthur_client.api_bindings.models.patch_unregistered_agent_request import PatchUnregisteredAgentRequest
from arthur_client.api_bindings.models.patch_user import PatchUser
from arthur_client.api_bindings.models.patch_webhook import PatchWebhook
from arthur_client.api_bindings.models.patch_workspace import PatchWorkspace
from arthur_client.api_bindings.models.permission import Permission
from arthur_client.api_bindings.models.permission_name import PermissionName
from arthur_client.api_bindings.models.permission_request_item import PermissionRequestItem
from arthur_client.api_bindings.models.permission_response_item import PermissionResponseItem
from arthur_client.api_bindings.models.permissions_request import PermissionsRequest
from arthur_client.api_bindings.models.permissions_response import PermissionsResponse
from arthur_client.api_bindings.models.post_alert import PostAlert
from arthur_client.api_bindings.models.post_alert_rule import PostAlertRule
from arthur_client.api_bindings.models.post_alerts import PostAlerts
from arthur_client.api_bindings.models.post_connector_spec import PostConnectorSpec
from arthur_client.api_bindings.models.post_custom_aggregation_spec_schema import PostCustomAggregationSpecSchema
from arthur_client.api_bindings.models.post_custom_aggregation_test import PostCustomAggregationTest
from arthur_client.api_bindings.models.post_data_plane import PostDataPlane
from arthur_client.api_bindings.models.post_data_plane_association import PostDataPlaneAssociation
from arthur_client.api_bindings.models.post_data_retrieval_operation import PostDataRetrievalOperation
from arthur_client.api_bindings.models.post_dataset import PostDataset
from arthur_client.api_bindings.models.post_dataset_join_spec import PostDatasetJoinSpec
from arthur_client.api_bindings.models.post_end_user import PostEndUser
from arthur_client.api_bindings.models.post_global_role_binding import PostGlobalRoleBinding
from arthur_client.api_bindings.models.post_group import PostGroup
from arthur_client.api_bindings.models.post_group_membership import PostGroupMembership
from arthur_client.api_bindings.models.post_job import PostJob
from arthur_client.api_bindings.models.post_job_batch import PostJobBatch
from arthur_client.api_bindings.models.post_job_kind import PostJobKind
from arthur_client.api_bindings.models.post_job_spec import PostJobSpec
from arthur_client.api_bindings.models.post_link_task_request import PostLinkTaskRequest
from arthur_client.api_bindings.models.post_metrics_query import PostMetricsQuery
from arthur_client.api_bindings.models.post_metrics_query_result_filter import PostMetricsQueryResultFilter
from arthur_client.api_bindings.models.post_metrics_query_result_filter_and_group import PostMetricsQueryResultFilterAndGroup
from arthur_client.api_bindings.models.post_metrics_query_result_filter_and_group_and_inner import PostMetricsQueryResultFilterAndGroupAndInner
from arthur_client.api_bindings.models.post_metrics_query_result_filter_or_group import PostMetricsQueryResultFilterOrGroup
from arthur_client.api_bindings.models.post_metrics_query_result_filter_or_group_or_inner import PostMetricsQueryResultFilterOrGroupOrInner
from arthur_client.api_bindings.models.post_metrics_query_time_range import PostMetricsQueryTimeRange
from arthur_client.api_bindings.models.post_metrics_versions import PostMetricsVersions
from arthur_client.api_bindings.models.post_model import PostModel
from arthur_client.api_bindings.models.post_project import PostProject
from arthur_client.api_bindings.models.post_role_binding import PostRoleBinding
from arthur_client.api_bindings.models.post_service_account import PostServiceAccount
from arthur_client.api_bindings.models.post_task_request import PostTaskRequest
from arthur_client.api_bindings.models.post_task_validation_api_key import PostTaskValidationAPIKey
from arthur_client.api_bindings.models.post_upsolve_tenant import PostUpsolveTenant
from arthur_client.api_bindings.models.post_webhook import PostWebhook
from arthur_client.api_bindings.models.post_workspace import PostWorkspace
from arthur_client.api_bindings.models.project import Project
from arthur_client.api_bindings.models.project_bound_resource_metadata import ProjectBoundResourceMetadata
from arthur_client.api_bindings.models.project_sort import ProjectSort
from arthur_client.api_bindings.models.put_agents import PutAgents
from arthur_client.api_bindings.models.put_agents_response import PutAgentsResponse
from arthur_client.api_bindings.models.put_available_dataset import PutAvailableDataset
from arthur_client.api_bindings.models.put_available_datasets import PutAvailableDatasets
from arthur_client.api_bindings.models.put_custom_aggregation_spec_schema import PutCustomAggregationSpecSchema
from arthur_client.api_bindings.models.put_dataset_schema import PutDatasetSchema
from arthur_client.api_bindings.models.put_job_state import PutJobState
from arthur_client.api_bindings.models.put_model_metric_spec import PutModelMetricSpec
from arthur_client.api_bindings.models.put_model_metrics_schedule import PutModelMetricsSchedule
from arthur_client.api_bindings.models.put_retrieved_data import PutRetrievedData
from arthur_client.api_bindings.models.put_task_connection_info import PutTaskConnectionInfo
from arthur_client.api_bindings.models.put_task_state_cache_request import PutTaskStateCacheRequest
from arthur_client.api_bindings.models.put_unregistered_agents import PutUnregisteredAgents
from arthur_client.api_bindings.models.put_unregistered_agents_response import PutUnregisteredAgentsResponse
from arthur_client.api_bindings.models.reasoning_effort_enum import ReasoningEffortEnum
from arthur_client.api_bindings.models.regenerate_task_validation_key_job_spec import RegenerateTaskValidationKeyJobSpec
from arthur_client.api_bindings.models.regex_config import RegexConfig
from arthur_client.api_bindings.models.register_user import RegisterUser
from arthur_client.api_bindings.models.registered_agent_provider import RegisteredAgentProvider
from arthur_client.api_bindings.models.relevance_metric_config import RelevanceMetricConfig
from arthur_client.api_bindings.models.reported_custom_aggregation import ReportedCustomAggregation
from arthur_client.api_bindings.models.resource_kind import ResourceKind
from arthur_client.api_bindings.models.resource_list_agent_response import ResourceListAgentResponse
from arthur_client.api_bindings.models.resource_list_aggregation_spec_schema import ResourceListAggregationSpecSchema
from arthur_client.api_bindings.models.resource_list_alert_rule import ResourceListAlertRule
from arthur_client.api_bindings.models.resource_list_available_dataset import ResourceListAvailableDataset
from arthur_client.api_bindings.models.resource_list_connector_spec import ResourceListConnectorSpec
from arthur_client.api_bindings.models.resource_list_connector_type import ResourceListConnectorType
from arthur_client.api_bindings.models.resource_list_custom_aggregation_spec_schema import ResourceListCustomAggregationSpecSchema
from arthur_client.api_bindings.models.resource_list_custom_aggregation_test_result import ResourceListCustomAggregationTestResult
from arthur_client.api_bindings.models.resource_list_custom_aggregation_test_spec import ResourceListCustomAggregationTestSpec
from arthur_client.api_bindings.models.resource_list_data_plane import ResourceListDataPlane
from arthur_client.api_bindings.models.resource_list_data_plane_association import ResourceListDataPlaneAssociation
from arthur_client.api_bindings.models.resource_list_data_source import ResourceListDataSource
from arthur_client.api_bindings.models.resource_list_dataset import ResourceListDataset
from arthur_client.api_bindings.models.resource_list_group import ResourceListGroup
from arthur_client.api_bindings.models.resource_list_group_membership import ResourceListGroupMembership
from arthur_client.api_bindings.models.resource_list_job_error import ResourceListJobError
from arthur_client.api_bindings.models.resource_list_job_log import ResourceListJobLog
from arthur_client.api_bindings.models.resource_list_job_run import ResourceListJobRun
from arthur_client.api_bindings.models.resource_list_llm_model import ResourceListLLMModel
from arthur_client.api_bindings.models.resource_list_metrics_version import ResourceListMetricsVersion
from arthur_client.api_bindings.models.resource_list_model import ResourceListModel
from arthur_client.api_bindings.models.resource_list_permission import ResourceListPermission
from arthur_client.api_bindings.models.resource_list_project import ResourceListProject
from arthur_client.api_bindings.models.resource_list_role import ResourceListRole
from arthur_client.api_bindings.models.resource_list_role_binding import ResourceListRoleBinding
from arthur_client.api_bindings.models.resource_list_sub_agent import ResourceListSubAgent
from arthur_client.api_bindings.models.resource_list_tool import ResourceListTool
from arthur_client.api_bindings.models.resource_list_unregistered_agent_response import ResourceListUnregisteredAgentResponse
from arthur_client.api_bindings.models.resource_list_user import ResourceListUser
from arthur_client.api_bindings.models.resource_list_webhook import ResourceListWebhook
from arthur_client.api_bindings.models.resource_list_workspace import ResourceListWorkspace
from arthur_client.api_bindings.models.result_filter import ResultFilter
from arthur_client.api_bindings.models.role import Role
from arthur_client.api_bindings.models.role_binding import RoleBinding
from arthur_client.api_bindings.models.role_sort import RoleSort
from arthur_client.api_bindings.models.rule_response import RuleResponse
from arthur_client.api_bindings.models.rule_scope import RuleScope
from arthur_client.api_bindings.models.rule_type import RuleType
from arthur_client.api_bindings.models.scalar_type import ScalarType
from arthur_client.api_bindings.models.schedule_jobs_job_spec import ScheduleJobsJobSpec
from arthur_client.api_bindings.models.schema_inspection_job_spec import SchemaInspectionJobSpec
from arthur_client.api_bindings.models.scope_schema_tag import ScopeSchemaTag
from arthur_client.api_bindings.models.sensitive_data_plane import SensitiveDataPlane
from arthur_client.api_bindings.models.sensitive_user import SensitiveUser
from arthur_client.api_bindings.models.service_account_credentials import ServiceAccountCredentials
from arthur_client.api_bindings.models.sketch_custom_aggregation_test_result import SketchCustomAggregationTestResult
from arthur_client.api_bindings.models.sketch_metric import SketchMetric
from arthur_client.api_bindings.models.sketch_point import SketchPoint
from arthur_client.api_bindings.models.sketch_time_series import SketchTimeSeries
from arthur_client.api_bindings.models.sort_order import SortOrder
from arthur_client.api_bindings.models.sub_agent import SubAgent
from arthur_client.api_bindings.models.sub_agent_response import SubAgentResponse
from arthur_client.api_bindings.models.task_connection_info import TaskConnectionInfo
from arthur_client.api_bindings.models.task_mutation_response import TaskMutationResponse
from arthur_client.api_bindings.models.task_read_response import TaskReadResponse
from arthur_client.api_bindings.models.task_response import TaskResponse
from arthur_client.api_bindings.models.task_type import TaskType
from arthur_client.api_bindings.models.task_validation_api_key import TaskValidationAPIKey
from arthur_client.api_bindings.models.task_validation_key_regeneration_response import TaskValidationKeyRegenerationResponse
from arthur_client.api_bindings.models.test_custom_aggregation_job_spec import TestCustomAggregationJobSpec
from arthur_client.api_bindings.models.tool import Tool
from arthur_client.api_bindings.models.tool_argument import ToolArgument
from arthur_client.api_bindings.models.tool_argument_response import ToolArgumentResponse
from arthur_client.api_bindings.models.tool_response import ToolResponse
from arthur_client.api_bindings.models.toxicity_config import ToxicityConfig
from arthur_client.api_bindings.models.trace_transform_definition import TraceTransformDefinition
from arthur_client.api_bindings.models.trace_transform_response import TraceTransformResponse
from arthur_client.api_bindings.models.trace_transform_variable_definition import TraceTransformVariableDefinition
from arthur_client.api_bindings.models.unregistered_agent import UnregisteredAgent
from arthur_client.api_bindings.models.unregistered_agent_response import UnregisteredAgentResponse
from arthur_client.api_bindings.models.update_model_task_rules_job_spec import UpdateModelTaskRulesJobSpec
from arthur_client.api_bindings.models.upsolve_token import UpsolveToken
from arthur_client.api_bindings.models.user import User
from arthur_client.api_bindings.models.user_credentials import UserCredentials
from arthur_client.api_bindings.models.user_service_account_credentials import UserServiceAccountCredentials
from arthur_client.api_bindings.models.user_sort import UserSort
from arthur_client.api_bindings.models.user_type import UserType
from arthur_client.api_bindings.models.validate_alert_rule_query_req import ValidateAlertRuleQueryReq
from arthur_client.api_bindings.models.validation_error import ValidationError
from arthur_client.api_bindings.models.validation_error_loc_inner import ValidationErrorLocInner
from arthur_client.api_bindings.models.validation_outcome import ValidationOutcome
from arthur_client.api_bindings.models.validation_result import ValidationResult
from arthur_client.api_bindings.models.validation_results import ValidationResults
from arthur_client.api_bindings.models.value import Value
from arthur_client.api_bindings.models.webhook import Webhook
from arthur_client.api_bindings.models.webhook_response import WebhookResponse
from arthur_client.api_bindings.models.webhook_result import WebhookResult
from arthur_client.api_bindings.models.webhook_sort import WebhookSort
from arthur_client.api_bindings.models.workspace import Workspace
from arthur_client.api_bindings.models.workspace_sort import WorkspaceSort
from arthur_client.api_bindings.models.workspace_statistics import WorkspaceStatistics



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.unregistered_agent_response import UnregisteredAgentResponse

class TestUnregisteredAgentResponse(unittest.TestCase):
    """UnregisteredAgentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UnregisteredAgentResponse:
        """Test UnregisteredAgentResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UnregisteredAgentResponse`
        """
        model = UnregisteredAgentResponse()
        if include_optional:
            return UnregisteredAgentResponse(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                name = '',
                creation_source = arthur_client.api_bindings.models.creation_source.CreationSource(
                    task_id = '', 
                    top_level_span_name = '', 
                    gcp_project_id = '', 
                    gcp_region = '', 
                    gcp_reasoning_engine_id = '', ),
                first_detected = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                num_spans = 56,
                infrastructure = 'AWS',
                data_plane_id = '',
                tools = [
                    arthur_client.api_bindings.models.tool_response.ToolResponse(
                        id = '', 
                        name = '', 
                        arguments = [
                            arthur_client.api_bindings.models.tool_argument_response.ToolArgumentResponse(
                                id = '', 
                                name = '', 
                                type = '', )
                            ], )
                    ],
                sub_agents = [
                    arthur_client.api_bindings.models.sub_agent_response.SubAgentResponse(
                        id = '', 
                        name = '', )
                    ],
                model_id = '',
                model_name = ''
            )
        else:
            return UnregisteredAgentResponse(
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                id = '',
                name = '',
                creation_source = arthur_client.api_bindings.models.creation_source.CreationSource(
                    task_id = '', 
                    top_level_span_name = '', 
                    gcp_project_id = '', 
                    gcp_region = '', 
                    gcp_reasoning_engine_id = '', ),
                first_detected = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                infrastructure = 'AWS',
                data_plane_id = '',
        )
        """

    def testUnregisteredAgentResponse(self):
        """Test UnregisteredAgentResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.models.permissions_response import PermissionsResponse

class TestPermissionsResponse(unittest.TestCase):
    """PermissionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PermissionsResponse:
        """Test PermissionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PermissionsResponse`
        """
        model = PermissionsResponse()
        if include_optional:
            return PermissionsResponse(
                permissions = [
                    arthur_client.api_bindings.models.permission_response_item.PermissionResponseItem(
                        resource_kind = 'platform', 
                        resource_id = '', 
                        permission_name = 'organization_read', 
                        allowed = True, )
                    ]
            )
        else:
            return PermissionsResponse(
                permissions = [
                    arthur_client.api_bindings.models.permission_response_item.PermissionResponseItem(
                        resource_kind = 'platform', 
                        resource_id = '', 
                        permission_name = 'organization_read', 
                        allowed = True, )
                    ],
        )
        """

    def testPermissionsResponse(self):
        """Test PermissionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
